Revision: 9657
          
http://languagetool.svn.sourceforge.net/languagetool/?rev=9657&view=rev
Author:   dnaber
Date:     2013-03-10 11:59:21 +0000 (Sun, 10 Mar 2013)
Log Message:
-----------
keep snapshots for 10 days now; change the way we build so 
language-module.properties is correct

Modified Paths:
--------------
    trunk/website/create-snapshot.sh

Modified: trunk/website/create-snapshot.sh
===================================================================
--- trunk/website/create-snapshot.sh    2013-03-10 11:56:03 UTC (rev 9656)
+++ trunk/website/create-snapshot.sh    2013-03-10 11:59:21 UTC (rev 9657)
@@ -10,12 +10,19 @@
 M2_HOME=/home/languagetool/apache-maven-3.0.4
 M2=$M2_HOME/bin
 PATH=$M2:$PATH
-MAVEN_OPTS=-Xmx512m -XX:MaxPermSize=128m
+MAVEN_OPTS="-Xmx512m -XX:MaxPermSize=128m"
 
-mvn clean package -DskipTests && 
- mv languagetool-office-extension/target/LanguageTool*.zip 
$SNAPSHOT_DIR/LanguageTool-`date +%Y%m%d`-snapshot.oxt &&
- mv languagetool-standalone/target/LanguageTool*.zip 
$SNAPSHOT_DIR/LanguageTool-`date +%Y%m%d`-snapshot.zip
+# We need to build like this - building the top-level project and then taking 
the
+# artifacts will aggregate *all* languages into the 
language-module.properties, even
+# for those projects that don't depend on all of the languages:
+mvn clean &&
+mvn --projects languagetool-office-extension --also-make package -DskipTests &&
+mv languagetool-office-extension/target/LanguageTool*.zip 
$SNAPSHOT_DIR/LanguageTool-`date +%Y%m%d`-snapshot.oxt &&
+mvn --projects languagetool-standalone --also-make package -DskipTests &&
+mv languagetool-standalone/target/LanguageTool*.zip 
$SNAPSHOT_DIR/LanguageTool-`date +%Y%m%d`-snapshot.zip &&
+mvn --projects languagetool-wikipedia --also-make package -DskipTests &&
+mv languagetool-wikipedia/target/LanguageTool*.zip 
$SNAPSHOT_DIR/LanguageTool-wikipedia-`date +%Y%m%d`-snapshot.zip
 
-# delete *.oxt files older than 5 days:
-rm `find $SNAPSHOT_DIR -name "*.oxt" -mtime +5`
-rm `find $SNAPSHOT_DIR -name "*.zip" -mtime +5`
+# delete files older than 10 days:
+rm `find $SNAPSHOT_DIR -name "*.oxt" -mtime +10`
+rm `find $SNAPSHOT_DIR -name "*.zip" -mtime +10`

This was sent by the SourceForge.net collaborative development platform, the 
world's largest Open Source development site.


------------------------------------------------------------------------------
Symantec Endpoint Protection 12 positioned as A LEADER in The Forrester  
Wave(TM): Endpoint Security, Q1 2013 and "remains a good choice" in the  
endpoint security space. For insight on selecting the right partner to 
tackle endpoint security challenges, access the full report. 
http://p.sf.net/sfu/symantec-dev2dev
_______________________________________________
Languagetool-commits mailing list
[email protected]
https://lists.sourceforge.net/lists/listinfo/languagetool-commits

Reply via email to